Summary:     UCX is a communication library implementing high-performance messaging
Name:        ucx
Version:     1.14.1
Release:     3%{?dist}
License:     BSD
URL:         http://www.openucx.org
Source0:     https://github.com/openucx/ucx/archive/refs/tags/v%{version}.tar.gz
Patch0:      0001-ucx-1.14.1-add-support-for-loongarch64.patch

BuildRequires: automake autoconf libtool gcc-c++
BuildRequires: numactl-devel libibverbs-devel librdmacm-devel
BuildRequires: glibc-devel >= 2.15

ExclusiveArch: aarch64 x86_64


%description
UCX is an optimized communication framework for high-performance distributed
applications. UCX utilizes high-speed networks, such as RDMA (InfiniBand, RoCE,
etc), Cray Gemini or Aries, for inter-node communication. If no such network is
available, TCP is used instead. UCX supports efficient transfer of data in
either main memory (RAM) or GPU memory (through CUDA and ROCm libraries). In
addition, UCX provides efficient intra-node communication, by leveraging the
following shared memory mechanisms: posix, sysv, cma, knem, and xpmem.
The acronym UCX stands for "Unified Communication X".

%package devel
Requires: %{name} = %{version}-%{release}
Summary: Header files required for developing with UCX

%description devel
Provides header files and examples for developing with UCX.

%prep
%autosetup -p1

%build
./autogen.sh
%configure --disable-optimizations \
           --disable-logging \
           --disable-debug \
           --disable-assertions \
           --disable-params-check \
           --without-java \
           --with-cma  \
           --without-cuda  \
           --without-gdrcopy  \
           --with-verbs  \
           --without-knem  \
           --with-rdmacm  \
           --without-rocm  \
           --without-xpmem  \
           --without-fuse3  \
           --without-ugni

%make_build

%install
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/*.a
rm -f %{buildroot}%{_libdir}/ucx/*.la
rm -f %{buildroot}%{_libdir}/ucx/lib*.so
rm -f %{buildroot}%{_libdir}/ucx/lib*.a

%files
%license LICENSE
%doc README AUTHORS NEWS
%{_libdir}/lib*.so.*
%{_bindir}/ucx_info
%{_bindir}/ucx_perftest
%{_bindir}/ucx_read_profile
%{_bindir}/io_demo
%{_datadir}/ucx
%exclude %{_datadir}/ucx/examples


%files devel
%{_includedir}/uc*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/ucx.pc
%{_libdir}/pkgconfig/ucx-cma.pc
%{_libdir}/pkgconfig/ucx-ib.pc
%{_libdir}/pkgconfig/ucx-rdmacm.pc
%{_libdir}/pkgconfig/ucx-ucs.pc
%{_libdir}/pkgconfig/ucx-uct.pc
%{_libdir}/cmake/ucx/*.cmake
%{_datadir}/ucx/examples

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%package cma
Requires: %{name} = %{version}-%{release}
Summary: UCX CMA support

%description cma
Provides CMA (Linux cross-memory-attach) transport for UCX. It utilizes the
system calls process_vm_readv/writev() for one-shot memory copy from another
process.

%files cma
%{_libdir}/ucx/libuct_cma.so.*

%package ib
Requires: %{name} = %{version}-%{release}
Summary: UCX RDMA support

%description ib
Provides support for IBTA-compliant transports for UCX. This includes RoCE,
InfiniBand, OmniPath, and any other transport supported by IB Verbs API.
Typically these transports provide RDMA support, which enables a fast and
hardware-offloaded data transfer.

%files ib
%{_libdir}/ucx/libuct_ib.so.*

%package rdmacm
Requires: %{name} = %{version}-%{release}
Summary: UCX RDMA connection manager support

%description rdmacm
Provides RDMA connection-manager support to UCX, which enables client/server
based connection establishment for RDMA-capable transports.

%files rdmacm
%{_libdir}/ucx/libuct_rdmacm.so.*

%changelog
* Tue Mar 19 2024 doupengda <doupengda@loongson.cn> - 1.14.1-3
- add support for loongarch64

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.1-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 17 2023 Miaojun Dong <zoedong@tencent.com> - 1.14.1-1
- Bump version to 1.14.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.13.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.13.1-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Nov 18 2022 Miaojun Dong <zoedong@tencent.com> - 1.13.1-1
- Initial build
